@@ -1,11 +1,11 @@
 from pprint import pprint
 
-from examples.datasets.linear import LinearRegressionDataset
-from pytolemaic.pytrust import PyTrust
+from pytolemaic import Metrics
+from pytolemaic import PyTrust
 ## For this example we create train/test data representing a linear function
 # both numpy and pandas.DataFrame is ok.
 from pytolemaic.utils.dmd import DMD
-from pytolemaic.utils.metrics import Metrics
+from resources.datasets.linear import LinearRegressionDataset
 
 
 def run():
@@ -44,7 +44,7 @@ def run():
         metric=metric,
         splitter=splitter)
 
-    quality_report = pytrust.create_quality_report()
+    quality_report = pytrust.quality_report
     print("Quality report - higher is better")
     pprint(quality_report.to_dict(printable=True), width=120)
     pprint(quality_report.to_dict_meaning(), width=120)
